==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerStatusFluent<A extends ACMEIssuerStatusFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerStatusFluent() {
  }
  public ACMEIssuerStatusFluent(ACMEIssuerStatus instance) {
    instance = (instance != null ? instance : new ACMEIssuerStatus());

    if (instance != null) {
      this.withLastRegisteredEmail(instance.getLastRegisteredEmail());
      this.withUri(instance.getUri());
      this.withLastRegisteredEmail(instance.getLastRegisteredEmail());
      this.withUri(instance.getUri());
    }
  }
  private String lastRegisteredEmail;
  private String uri;
  public String getLastRegisteredEmail() {
    return this.lastRegisteredEmail;
  }
  public A withLastRegisteredEmail(String lastRegisteredEmail) {
    this.lastRegisteredEmail=lastRegisteredEmail; return (A) this;
  }
  public boolean hasLastRegisteredEmail() {
    return this.lastRegisteredEmail != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerStatusFluent that = (ACMEIssuerStatusFluent) o;
    if (!java.util.Objects.equals(lastRegisteredEmail, that.lastRegisteredEmail)) return false;

    if (!java.util.Objects.equals(uri, that.uri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lastRegisteredEmail,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRegisteredEmail != null) { sb.append("lastRegisteredEmail:"); sb.append(lastRegisteredEmail + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEIssuerStatusFluent<A extends ACMEIssuerStatusFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerStatusFluent() {
  }
  
  public ACMEIssuerStatusFluent(ACMEIssuerStatus instance) {
    this.copyInstance(instance);
  }
  private String lastRegisteredEmail;
  private String uri;
  
  protected void copyInstance(ACMEIssuerStatus instance) {
    instance = (instance != null ? instance : new ACMEIssuerStatus());
  
    if (instance != null) {
        this.withLastRegisteredEmail(instance.getLastRegisteredEmail());
        this.withUri(instance.getUri());
        this.withLastRegisteredEmail(instance.getLastRegisteredEmail());
        this.withUri(instance.getUri());
      }
  }
  
  public String getLastRegisteredEmail() {
    return this.lastRegisteredEmail;
  }
  
  public A withLastRegisteredEmail(String lastRegisteredEmail) {
    this.lastRegisteredEmail=lastRegisteredEmail; return (A) this;
  }
  
  public boolean hasLastRegisteredEmail() {
    return this.lastRegisteredEmail != null;
  }
  
  public String getUri() {
    return this.uri;
  }
  
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  
  public boolean hasUri() {
    return this.uri != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerStatusFluent that = (ACMEIssuerStatusFluent) o;
    if (!java.util.Objects.equals(lastRegisteredEmail, that.lastRegisteredEmail)) return false;
  
    if (!java.util.Objects.equals(uri, that.uri)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastRegisteredEmail,  uri,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastRegisteredEmail != null) { sb.append("lastRegisteredEmail:"); sb.append(lastRegisteredEmail + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  

}
